@@ -437,15 +437,15 @@ class Base(Controller):
         help='Operations on the SSH config',
         arguments=[
             (['action'],{
-                "help" : "To show one of {set, ls, update}.",
+                "help" : "To show one of {set, ls, update}. Set is for new remote value, update is to grab from AWS",
                 "action" : "store"
             }),
             (['-host'],{
-            "help" : "Which SSH config host to change",
+            "help" : "Which SSH config host to SET",
             "action": "store"
             }),
             (['-ip'],{
-                "help" : "The IP to update in the ssh config as HostName",
+                "help" : "The IP to SET in the ssh config as HostName",
                 "action" : "store"
             })
         ]
@@ -453,9 +453,10 @@ class Base(Controller):
     def ssh(self):
         from ..ext.sshconf import read_ssh_config
         if self.app.pargs.action=='set':
-            ssh_config_obj = read_ssh_config('/Users/jakub/.ssh/config')
+            ssh_config_path = os.path.expanduser('~/.ssh/config')
+            ssh_config_obj = read_ssh_config(ssh_config_path)
             ssh_config_obj.set(self.app.pargs.host, HostName=self.app.pargs.ip)
-            ssh_config_obj.write('/Users/jakub/.ssh/config')
+            ssh_config_obj.write(ssh_config_path)
             print(ssh_config_obj.config())
 
         elif self.app.pargs.action=='update':
