@@ -1,8 +1,8 @@
 import boto3
 import warnings
-import ipdb
 warnings.simplefilter(action='ignore')
 import pandas as pd
+import os
 import humanize
 
 def parse_keys(x):
@@ -53,9 +53,13 @@ def get_ec2(status: str, profile: str, filter: str):
 
 def update_ec2_ssh(profile: str):
     from .sshconf import read_ssh_config
+
+    # get ssh config path and expand user path
+    ssh_path = os.path.expanduser(os.path.join('~', '.ssh', 'config'))
+
     # get ec2 and ssh config to get hosts
     running_instances = get_ec2("running", profile=profile, filter='live').T
-    ssh_config_obj = read_ssh_config('/Users/jakub/.ssh/config')
+    ssh_config_obj = read_ssh_config(ssh_path)
     hosts = ssh_config_obj.hosts()
     changes = {}
 
@@ -71,7 +75,7 @@ def update_ec2_ssh(profile: str):
         if target_host in ssh_config_obj.hosts_:
             ssh_config_obj.set(target_host, HostName=target_ip)
             changes[target_host] = target_ip
-            ssh_config_obj.write('/Users/jakub/.ssh/config')
+            ssh_config_obj.write(ssh_path)
         else:
             print(f'Could not find {target_host} in SSH config.')
 
