@@ -17,6 +17,12 @@ def d(variable, search: str):
         if check_docs(variable, search, m):
             doc = getattr(variable,m).__doc__
             tar = doc.index(search)
-            print(tar)
+
+            # TODO: add excluded terms in some way
             print(f"\x1b[0m \x1B[1m {m}:")
-            print(f"\x1b[0m{doc[tar-100:tar-5]}\x1b[31m{doc[tar-5:tar+5]}\x1b[0m{doc[tar+5:tar+100]}" )
\ No newline at end of file
+            print(f"\x1b[0m{doc[tar-100:tar-5]}\x1b[31m{doc[tar-5:tar+5]}\x1b[0m{doc[tar+5:tar+100]}" )
+
+
+def a(variable):
+    methods = dir(variable)
+    return { m:getattr(variable, m) for m in methods if not m.startswith('_') }
\ No newline at end of file
